@@ -9,11 +9,11 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.CodeGuruProfiler 1.17.102\n"
-        "Version:         1.17.102.post1\n"
-        "Builder version: 4.21.0\n"
+        "Type annotations for boto3.CodeGuruProfiler 1.17.108\n"
+        "Version:         1.17.108\n"
+        "Builder version: 4.22.1\n"
         "Docs:            https://pypi.org/project/mypy-boto3-codeguruprofiler/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codeguruprofiler.html#CodeGuruProfiler\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/codeguruprofiler.html#CodeGuruProfiler\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
@@ -23,7 +23,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.17.102.post1")
+    print("1.17.108")
 
 
 def main() -> None:
